diff mbox series

[next] RDMA/bnxt_re: Fix spelling mistake "priviledged" -> "privileged"

Message ID 20230626083535.53303-1-colin.i.king@gmail.com (mailing list archive)
State Accepted
Delegated to: Jason Gunthorpe
Headers show
Series [next] RDMA/bnxt_re: Fix spelling mistake "priviledged" -> "privileged" | expand

Commit Message

Colin Ian King June 26, 2023, 8:35 a.m. UTC
There is a spelling mistake in a comment and in a dev_err error message.
Fix them.

Signed-off-by: Colin Ian King <colin.i.king@gmail.com>
---
 drivers/infiniband/hw/bnxt_re/qplib_res.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

Comments

Jason Gunthorpe June 26, 2023, 2:03 p.m. UTC | #1
On Mon, Jun 26, 2023 at 09:35:35AM +0100, Colin Ian King wrote:
> There is a spelling mistake in a comment and in a dev_err error message.
> Fix them.
> 
> Signed-off-by: Colin Ian King <colin.i.king@gmail.com>
> ---
>  drivers/infiniband/hw/bnxt_re/qplib_res.c | 4 ++--
>  1 file changed, 2 insertions(+), 2 deletions(-)

Applied to for-next, thanks

Jason
diff mbox series

Patch

diff --git a/drivers/infiniband/hw/bnxt_re/qplib_res.c b/drivers/infiniband/hw/bnxt_re/qplib_res.c
index 1c6c6c0bcf52..5fd8f7c90bb0 100644
--- a/drivers/infiniband/hw/bnxt_re/qplib_res.c
+++ b/drivers/infiniband/hw/bnxt_re/qplib_res.c
@@ -726,7 +726,7 @@  int bnxt_qplib_alloc_dpi(struct bnxt_qplib_res *res,
 
 	switch (type) {
 	case BNXT_QPLIB_DPI_TYPE_KERNEL:
 		/* priviledged dbr was already mapped just initialize it. */
 		dpi->umdbr = dpit->ucreg.bar_base +
 			     dpit->ucreg.offset + bit_num * PAGE_SIZE;
 		dpi->dbr = dpit->priv_db;
@@ -932,7 +932,7 @@  int bnxt_qplib_map_db_bar(struct bnxt_qplib_res *res)
 	}
 	ucreg->bar_reg = ioremap(ucreg->bar_base, ucreg->len);
 	if (!ucreg->bar_reg) {
-		dev_err(&res->pdev->dev, "priviledged dpi map failed!");
+		dev_err(&res->pdev->dev, "privileged dpi map failed!");
 		return -ENOMEM;
 	}
@@ -726,7 +726,7 @@  int bnxt_qplib_alloc_dpi(struct bnxt_qplib_res *res,
 	switch (type) {
 	case BNXT_QPLIB_DPI_TYPE_KERNEL:
-		/* priviledged dbr was already mapped just initialize it. */
+		/* privileged dbr was already mapped just initialize it. */
 		dpi->umdbr = dpit->ucreg.bar_base +
 			     dpit->ucreg.offset + bit_num * PAGE_SIZE;